@@ -67,10 +67,7 @@ LdapServer &LdapServer::operator=(const LdapServer &that)
     return *this;
 }
 
-LdapServer::~LdapServer()
-{
-    delete d;
-}
+LdapServer::~LdapServer() = default;
 
 void LdapServer::clear()
 {
@@ -323,7 +320,7 @@ void LdapServer::setUrl(const LdapUrl &url)
         d->mAuth = Simple;
         d->mBindDn = url.extension(QStringLiteral("bindname"), critical);
     } else {
-        QString user = url.userName();
+        const QString user = url.userName();
         if (user.isEmpty()) {
             d->mAuth = Anonymous;
         } else {
