@@ -56,10 +56,7 @@ LdapUrl &LdapUrl::operator=(const LdapUrl &that)
     return *this;
 }
 
-LdapUrl::~LdapUrl()
-{
-    delete d;
-}
+LdapUrl::~LdapUrl() = default;
 
 void LdapUrl::setDn(const LdapDN &dn)
 {
@@ -77,7 +74,7 @@ LdapDN LdapUrl::dn() const
     if (tmp.startsWith(QLatin1Char('/'))) {
         tmp = tmp.mid(1);
     }
-    LdapDN tmpDN(tmp);
+    const LdapDN tmpDN(tmp);
     return tmpDN;
 }
 
@@ -260,7 +257,8 @@ void LdapUrl::parseQuery()
         }
     }
 
-    QString name, value;
+    QString name;
+    QString value;
     QStringList::const_iterator end2(extensions.constEnd());
     for (QStringList::const_iterator it = extensions.constBegin(); it != end2; ++it) {
         ext.critical = false;
